@@ -1,6 +1,6 @@
 package Catalyst::Script::Bar;
 use Moose;
-use namespace::clean -except => [ 'meta' ];
+use namespace::autoclean;
 
 with 'Catalyst::ScriptRole';
 
